'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var defaultOptions = {
  rubyBase: 10,
  rubyText: 10,
  useStringLength: false
};

var _module = function module(context) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var {
    Syntax,
    RuleError,
    report
  } = context;
  var rubyBaseMax = options.rubyBase ? options.rubyBase : defaultOptions.rubyBase;
  var rubyTextMax = options.rubyText ? options.rubyText : defaultOptions.rubyText;
  var useStringLength = typeof options.useStringLength === 'boolean' ? options.useStringLength : defaultOptions.useStringLength;
  var RubyBase = 'RubyBase';
  var RubyText = 'RubyText';
  return {
    [Syntax.Str](node) {
      var text = node.value;
      var len = getLength(text, useStringLength);

      if (isNodeWrapped(node, [RubyBase])) {
        if (len > rubyBaseMax) {
          report(node, new RuleError("\u30EB\u30D3\u89AA\u6587\u5B57\u304C\u9577\u3059\u304E\u307E\u3059: ".concat(len, "\u6587\u5B57 / ").concat(rubyBaseMax, "\u6587\u5B57")));
        }
      }

      if (isNodeWrapped(node, [RubyText])) {
        if (len > rubyTextMax) {
          report(node, new RuleError("\u30EB\u30D3\u6587\u5B57\u304C\u9577\u3059\u304E\u307E\u3059: ".concat(len, "\u6587\u5B57 / ").concat(rubyTextMax, "\u6587\u5B57")));
        }
      }
    }

  };
};

function getLength(text, useStringLength) {
  if (useStringLength) {
    return text.length;
  }

  return [...text].length;
}
/**
 * Get parents of node.
 * The parent nodes are returned in order from the closest parent to the outer ones.
 * @param node
 * @returns {Array}
 */


function getParents(node) {
  var result = []; // child node has `parent` property.

  var parent = node.parent;

  while (parent != null) {
    result.push(parent);
    parent = parent.parent;
  }

  return result;
}
/**
 * Return true if `node` is wrapped any one of `types`.
 * @param {TxtNode} node is target node
 * @param {string[]} types are wrapped target node
 * @returns {boolean|*}
 */


function isNodeWrapped(node, types) {
  var parents = getParents(node);
  var parentsTypes = parents.map(function (parent) {
    return parent.type;
  });
  return types.some(function (type) {
    return parentsTypes.some(function (parentType) {
      return parentType === type;
    });
  });
}

var _default = _module;
exports.default = _default;
//# sourceMappingURL=textlint-rule-max-ruby-len.js.map